# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.response_wrapper_rag_query_response import ResponseWrapperRagQueryResponse  # noqa: E501

class TestResponseWrapperRagQueryResponse(unittest.TestCase):
    """ResponseWrapperRagQueryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperRagQueryResponse:
        """Test ResponseWrapperRagQueryResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperRagQueryResponse`
        """
        model = ResponseWrapperRagQueryResponse()  # noqa: E501
        if include_optional:
            return ResponseWrapperRagQueryResponse(
                done = True,
                error = '',
                result = ai_assistant_server_connector.models.rag_query_response.RagQueryResponse(
                    available_free = [
                        ai_assistant_server_connector.models.search_result.SearchResult(
                            metadata = ai_assistant_server_connector.models.metadata.Metadata(), 
                            score = null, 
                            text = '', )
                        ], 
                    available_paid = [
                        ai_assistant_server_connector.models.search_result.SearchResult(
                            metadata = ai_assistant_server_connector.models.metadata.Metadata(), 
                            score = null, 
                            text = '', )
                        ], 
                    owned = [
                        
                        ], )
            )
        else:
            return ResponseWrapperRagQueryResponse(
                done = True,
        )
        """

    def testResponseWrapperRagQueryResponse(self):
        """Test ResponseWrapperRagQueryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
