# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_new import AiAssistantNew  # noqa: E501

class TestAiAssistantNew(unittest.TestCase):
    """AiAssistantNew unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantNew:
        """Test AiAssistantNew
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantNew`
        """
        model = AiAssistantNew()  # noqa: E501
        if include_optional:
            return AiAssistantNew(
                allow_text = True,
                allow_voice = True,
                approved_urls = [
                    ''
                    ],
                avatar_id = '',
                banned_keywords = [
                    ''
                    ],
                conversation_starter = '',
                conversation_style = 'formal',
                function = 'support',
                goals = [
                    ai_assistant_server_connector.models.ai_assistant_goal_create.AiAssistantGoalCreate(
                        additional_prompt = '', 
                        course_ids = [
                            56
                            ], 
                        engagement = 0.0, 
                        engagement_opt_out_duration = 0.0, 
                        engagement_preset_id = 56, 
                        is_active = True, 
                        max_engagement_count = 0.0, 
                        max_engagement_period = 0.0, 
                        max_total_engagement_count = 0.0, 
                        name = '', 
                        page_url = '', 
                        primary_course_id = 56, )
                    ],
                is_active = True,
                is_live = True,
                lexicon_items = [
                    ai_assistant_server_connector.models.ai_assistant_lexicon_item_new.AiAssistantLexiconItemNew(
                        pronounciation = '', 
                        term = '', )
                    ],
                name = '',
                prefer_voice = True,
                system_prompt_support = '',
                system_prompt_tutor = '',
                voice_id = 56
            )
        else:
            return AiAssistantNew(
                name = '',
        )
        """

    def testAiAssistantNew(self):
        """Test AiAssistantNew"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
