# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr
from ai_assistant_server_connector.models.response_chunk_type import ResponseChunkType
from ai_assistant_server_connector.models.usage_details import UsageDetails

class ResponseChunk(BaseModel):
    """
    ResponseChunk  # noqa: E501
    """
    text: Optional[StrictStr] = None
    type: Optional[ResponseChunkType] = None
    usage_details: Optional[UsageDetails] = None
    __properties = ["text", "type", "usage_details"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResponseChunk:
        """Create an instance of ResponseChunk from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of usage_details
        if self.usage_details:
            _dict['usage_details'] = self.usage_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResponseChunk:
        """Create an instance of ResponseChunk from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResponseChunk.parse_obj(obj)

        _obj = ResponseChunk.parse_obj({
            "text": obj.get("text"),
            "type": obj.get("type"),
            "usage_details": UsageDetails.from_dict(obj.get("usage_details")) if obj.get("usage_details") is not None else None
        })
        return _obj


